#ifndef OBJMODEL_H
#define OBJMODEL_H

#include <cstdio>
#include <iostream>


typedef struct VertexOBJ
{
  float Position[3];
  float Normal[3];
  float Texture[2];
} VertexOBJ;



// very simple wavefront obj parser, only triangles, doesn't care about groups,
// assumes single texture, whose name is stored in mtl file with same name

class OBJModel {

public:

    OBJModel(const char *fileName, float scale);
    ~OBJModel();

    // Returns vertex data stored in the OpenGL compatible format (with z-axis pointing towards observer)
    const VertexOBJ* getVerticesGL() { return(_verticesGL); };
    int getNVerticesGL() { return(_nVerticesGL); };

    // Returns vertex positions (no redundancy) in world coordinates
    // (z-axis points away from observer)
    const float* getPositions() { return(_positions); };
    int getNPositions() { return(_nPositions); };

    std::string getImageFileName() { return(_imgFileName); };

    // Applies two rigid body motions to vertices and returns maximal distance of corresponding vertices
    float maximalDistance(const float *T1, const float *R_mat1, const float *T2, const float *R_mat2);


private:

    void readFile(FILE *objFile);
    void readMTLFile(const char *mtlFileName);

    std::string _imgFileName;
    float _scale;
    VertexOBJ *_verticesGL;
    int _nVerticesGL; // for openGL (with redundancy)
//    int _nVertices, _nTexCoords, _nNormals, _nTriangles; // in the object file (no redundancy)
    int _nPositions; // without redundancy (from the object file)
    float *_positions; // vertex positions (no doubles and z-axis away from observer)

};

#endif // OBJMODEL_H
